diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/README.md b/lib/node_modules/@stdlib/stats/base/dstdev/README.md
index 6c24c69905f8..2b6c92047a90 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/README.md
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/README.md
@@ -98,17 +98,16 @@ The use of the term `n-1` is commonly referred to as Bessel's correction. Note,
var dstdev = require( '@stdlib/stats/base/dstdev' );
```
-#### dstdev( N, correction, x, stride )
+#### dstdev( N, correction, x, strideX )
-Computes the [standard deviation][standard-deviation] of a double-precision floating-point strided array `x`.
+Computes the [standard deviation][standard-deviation] of a double-precision floating-point strided array.
```javascript
var Float64Array = require( '@stdlib/array/float64' );
var x = new Float64Array( [ 1.0, -2.0, 2.0 ] );
-var N = x.length;
-var v = dstdev( N, 1, x, 1 );
+var v = dstdev( x.length, 1, x, 1 );
// returns ~2.0817
```
@@ -117,18 +116,16 @@ The function has the following parameters:
- **N**: number of indexed elements.
- **correction**: degrees of freedom adjustment. Setting this parameter to a value other than `0` has the effect of adjusting the divisor during the calculation of the [standard deviation][standard-deviation] according to `N-c` where `c` corresponds to the provided degrees of freedom adjustment. When computing the [standard deviation][standard-deviation] of a population, setting this parameter to `0` is the standard choice (i.e., the provided array contains data constituting an entire population). When computing the corrected sample [standard deviation][standard-deviation], setting this parameter to `1` is the standard choice (i.e., the provided array contains data sampled from a larger population; this is commonly referred to as Bessel's correction).
- **x**: input [`Float64Array`][@stdlib/array/float64].
-- **stride**: index increment for `x`.
+- **strideX**: stride length for `x`.
-The `N` and `stride` parameters determine which elements in `x` are accessed at runtime. For example, to compute the [standard deviation][standard-deviation] of every other element in `x`,
+The `N` and stride parameters determine which elements in the strided array are accessed at runtime. For example, to compute the [standard deviation][standard-deviation] of every other element in `x`,
```javascript
var Float64Array = require( '@stdlib/array/float64' );
-var floor = require( '@stdlib/math/base/special/floor' );
var x = new Float64Array( [ 1.0, 2.0, 2.0, -7.0, -2.0, 3.0, 4.0, 2.0 ] );
-var N = floor( x.length / 2 );
-var v = dstdev( N, 1, x, 2 );
+var v = dstdev( 4, 1, x, 2 );
// returns 2.5
```
@@ -138,18 +135,15 @@ Note that indexing is relative to the first index. To introduce an offset, use [
```javascript
var Float64Array = require( '@stdlib/array/float64' );
-var floor = require( '@stdlib/math/base/special/floor' );
var x0 = new Float64Array( [ 2.0, 1.0, 2.0, -2.0, -2.0, 2.0, 3.0, 4.0 ] );
var x1 = new Float64Array( x0.buffer, x0.BYTES_PER_ELEMENT*1 ); // start at 2nd element
-var N = floor( x0.length / 2 );
-
-var v = dstdev( N, 1, x1, 2 );
+var v = dstdev( 4, 1, x1, 2 );
// returns 2.5
```
-#### dstdev.ndarray( N, correction, x, stride, offset )
+#### dstdev.ndarray( N, correction, x, strideX, offsetX )
Computes the [standard deviation][standard-deviation] of a double-precision floating-point strided array using alternative indexing semantics.
@@ -157,26 +151,23 @@ Computes the [standard deviation][standard-deviation] of a double-precision floa
var Float64Array = require( '@stdlib/array/float64' );
var x = new Float64Array( [ 1.0, -2.0, 2.0 ] );
-var N = x.length;
-var v = dstdev.ndarray( N, 1, x, 1, 0 );
+var v = dstdev.ndarray( x.length, 1, x, 1, 0 );
// returns ~2.0817
```
The function has the following additional parameters:
-- **offset**: starting index for `x`.
+- **offsetX**: starting index for `x`.
-While [`typed array`][mdn-typed-array] views mandate a view offset based on the underlying `buffer`, the `offset` parameter supports indexing semantics based on a starting index. For example, to calculate the [standard deviation][standard-deviation] for every other value in `x` starting from the second value
+While [`typed array`][mdn-typed-array] views mandate a view offset based on the underlying buffer, the offset parameter supports indexing semantics based on a starting index. For example, to calculate the [standard deviation][standard-deviation] for every other element in `x` starting from the second element
```javascript
var Float64Array = require( '@stdlib/array/float64' );
-var floor = require( '@stdlib/math/base/special/floor' );
var x = new Float64Array( [ 2.0, 1.0, 2.0, -2.0, -2.0, 2.0, 3.0, 4.0 ] );
-var N = floor( x.length / 2 );
-var v = dstdev.ndarray( N, 1, x, 2, 1 );
+var v = dstdev.ndarray( 4, 1, x, 2, 1 );
// returns 2.5
```
@@ -202,18 +193,12 @@ var v = dstdev.ndarray( N, 1, x, 2, 1 );
```javascript
-var randu = require( '@stdlib/random/base/randu' );
-var round = require( '@stdlib/math/base/special/round' );
-var Float64Array = require( '@stdlib/array/float64' );
+var discreteUniform = require( '@stdlib/random/array/discrete-uniform' );
var dstdev = require( '@stdlib/stats/base/dstdev' );
-var x;
-var i;
-
-x = new Float64Array( 10 );
-for ( i = 0; i < x.length; i++ ) {
- x[ i ] = round( (randu()*100.0) - 50.0 );
-}
+var x = discreteUniform( 10, -50, 50, {
+ 'dtype': 'float64'
+});
console.log( x );
var v = dstdev( x.length, 1, x, 1 );
@@ -224,6 +209,125 @@ console.log( v );
+
+
+* * *
+
+
+
+## C APIs
+
+
+
+
+
+
+
+
+
+
+
+### Usage
+
+```c
+#include "stdlib/stats/base/dstdev.h"
+```
+
+#### stdlib_strided_dstdev( N, correction, \*X, strideX )
+
+Computes the [standard deviation][standard-deviation] of a double-precision floating-point strided array.
+
+```c
+const double x[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0 };
+
+double v = stdlib_strided_dstdev( 4, 1.0, x, 2 );
+// returns 2.581989
+```
+
+The function accepts the following arguments:
+
+- **N**: `[in] CBLAS_INT` number of indexed elements.
+- **correction**: `[in] double` degrees of freedom adjustment. Setting this parameter to a value other than `0` has the effect of adjusting the divisor during the calculation of the [standard deviation][standard-deviation] according to `N-c` where `c` corresponds to the provided degrees of freedom adjustment. When computing the [standard deviation][standard-deviation] of a population, setting this parameter to `0` is the standard choice (i.e., the provided array contains data constituting an entire population). When computing the corrected sample [standard deviation][standard-deviation], setting this parameter to `1` is the standard choice (i.e., the provided array contains data sampled from a larger population; this is commonly referred to as Bessel's correction).
+- **X**: `[in] double*` input array.
+- **strideX**: `[in] CBLAS_INT` stride length for `X`.
+
+```c
+double stdlib_strided_dstdev( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX );
+```
+
+#### stdlib_strided_dstdev_ndarray( N, correction, \*X, strideX, offsetX )
+
+Computes the [standard deviation][standard-deviation] of a double-precision floating-point strided array using alternative indexing semantics.
+
+```c
+const double x[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0 };
+
+double v = stdlib_strided_dstdev_ndarray( 4, 1.0, x, 2, 0 );
+// returns 2.581989
+```
+
+The function accepts the following arguments:
+
+- **N**: `[in] CBLAS_INT` number of indexed elements.
+- **correction**: `[in] double` degrees of freedom adjustment. Setting this parameter to a value other than `0` has the effect of adjusting the divisor during the calculation of the [standard deviation][standard-deviation] according to `N-c` where `c` corresponds to the provided degrees of freedom adjustment. When computing the [standard deviation][standard-deviation] of a population, setting this parameter to `0` is the standard choice (i.e., the provided array contains data constituting an entire population). When computing the corrected sample [standard deviation][standard-deviation], setting this parameter to `1` is the standard choice (i.e., the provided array contains data sampled from a larger population; this is commonly referred to as Bessel's correction).
+- **X**: `[in] double*` input array.
+- **strideX**: `[in] CBLAS_INT` stride length for `X`.
+- **offsetX**: `[in] CBLAS_INT` starting index for `X`.
+
+```c
+double stdlib_strided_dstdev_ndarray( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX, const CBLAS_INT offsetX );
+```
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+### Examples
+
+```c
+#include "stdlib/stats/base/dstdev.h"
+#include
+
+int main( void ) {
+ // Create a strided array:
+ const double x[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0 };
+
+ // Specify the number of elements:
+ const int N = 4;
+
+ // Specify the stride length:
+ const int strideX = 2;
+
+ // Compute the standard deviation:
+ double v = stdlib_strided_dstdev( N, 1.0, x, strideX );
+
+ // Print the result:
+ printf( "sample standard deviation: %lf\n", v );
+}
+```
+
+
+
+
+
+
+
+
+
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.js b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.js
index 8411e1b297bd..5316f918456b 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.js
@@ -21,14 +21,20 @@
// MODULES //
var bench = require( '@stdlib/bench' );
-var randu = require( '@stdlib/random/base/randu' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var pow = require( '@stdlib/math/base/special/pow' );
-var Float64Array = require( '@stdlib/array/float64' );
+var uniform = require( '@stdlib/random/array/uniform' );
var pkg = require( './../package.json' ).name;
var dstdev = require( './../lib/dstdev.js' );
+// VARIABLES //
+
+var options = {
+ 'dtype': 'float64'
+};
+
+
// FUNCTIONS //
/**
@@ -39,13 +45,7 @@ var dstdev = require( './../lib/dstdev.js' );
* @returns {Function} benchmark function
*/
function createBenchmark( len ) {
- var x;
- var i;
-
- x = new Float64Array( len );
- for ( i = 0; i < x.length; i++ ) {
- x[ i ] = ( randu()*20.0 ) - 10.0;
- }
+ var x = uniform( len, -10.0, 10.0, options );
return benchmark;
function benchmark( b ) {
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.native.js
index f9678e9fa786..e2d684f3076e 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.native.js
@@ -22,10 +22,9 @@
var resolve = require( 'path' ).resolve;
var bench = require( '@stdlib/bench' );
-var randu = require( '@stdlib/random/base/randu' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var pow = require( '@stdlib/math/base/special/pow' );
-var Float64Array = require( '@stdlib/array/float64' );
+var uniform = require( '@stdlib/random/array/uniform' );
var tryRequire = require( '@stdlib/utils/try-require' );
var pkg = require( './../package.json' ).name;
@@ -36,6 +35,9 @@ var dstdev = tryRequire( resolve( __dirname, './../lib/dstdev.native.js' ) );
var opts = {
'skip': ( dstdev instanceof Error )
};
+var options = {
+ 'dtype': 'float64'
+};
// FUNCTIONS //
@@ -48,13 +50,7 @@ var opts = {
* @returns {Function} benchmark function
*/
function createBenchmark( len ) {
- var x;
- var i;
-
- x = new Float64Array( len );
- for ( i = 0; i < x.length; i++ ) {
- x[ i ] = ( randu()*20.0 ) - 10.0;
- }
+ var x = uniform( len, -10.0, 10.0, options );
return benchmark;
function benchmark( b ) {
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.js b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.js
index 4184a3f9695b..822ca12a5f0c 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.js
@@ -21,14 +21,20 @@
// MODULES //
var bench = require( '@stdlib/bench' );
-var randu = require( '@stdlib/random/base/randu' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var pow = require( '@stdlib/math/base/special/pow' );
-var Float64Array = require( '@stdlib/array/float64' );
+var uniform = require( '@stdlib/random/array/uniform' );
var pkg = require( './../package.json' ).name;
var dstdev = require( './../lib/ndarray.js' );
+// VARIABLES //
+
+var options = {
+ 'dtype': 'float64'
+};
+
+
// FUNCTIONS //
/**
@@ -39,13 +45,7 @@ var dstdev = require( './../lib/ndarray.js' );
* @returns {Function} benchmark function
*/
function createBenchmark( len ) {
- var x;
- var i;
-
- x = new Float64Array( len );
- for ( i = 0; i < x.length; i++ ) {
- x[ i ] = ( randu()*20.0 ) - 10.0;
- }
+ var x = uniform( len, -10.0, 10.0, options );
return benchmark;
function benchmark( b ) {
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.native.js
index 498eedd0f332..b1dfa8a6ba1e 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/benchmark/benchmark.ndarray.native.js
@@ -22,10 +22,9 @@
var resolve = require( 'path' ).resolve;
var bench = require( '@stdlib/bench' );
-var randu = require( '@stdlib/random/base/randu' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var pow = require( '@stdlib/math/base/special/pow' );
-var Float64Array = require( '@stdlib/array/float64' );
+var uniform = require( '@stdlib/random/array/uniform' );
var tryRequire = require( '@stdlib/utils/try-require' );
var pkg = require( './../package.json' ).name;
@@ -36,6 +35,9 @@ var dstdev = tryRequire( resolve( __dirname, './../lib/ndarray.native.js' ) );
var opts = {
'skip': ( dstdev instanceof Error )
};
+var options = {
+ 'dtype': 'float64'
+};
// FUNCTIONS //
@@ -48,13 +50,7 @@ var opts = {
* @returns {Function} benchmark function
*/
function createBenchmark( len ) {
- var x;
- var i;
-
- x = new Float64Array( len );
- for ( i = 0; i < x.length; i++ ) {
- x[ i ] = ( randu()*20.0 ) - 10.0;
- }
+ var x = uniform( len, -10.0, 10.0, options );
return benchmark;
function benchmark( b ) {
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/docs/repl.txt b/lib/node_modules/@stdlib/stats/base/dstdev/docs/repl.txt
index 4b4da2655cb3..fed672b511bc 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/docs/repl.txt
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/docs/repl.txt
@@ -1,10 +1,10 @@
-{{alias}}( N, correction, x, stride )
+{{alias}}( N, correction, x, strideX )
Computes the standard deviation of a double-precision floating-point strided
array.
- The `N` and `stride` parameters determine which elements in `x` are accessed
- at runtime.
+ The `N` and stride parameters determine which elements in the strided array
+ are accessed at runtime.
Indexing is relative to the first index. To introduce an offset, use a typed
array view.
@@ -31,8 +31,8 @@
x: Float64Array
Input array.
- stride: integer
- Index increment.
+ strideX: integer
+ Stride length.
Returns
-------
@@ -46,22 +46,19 @@
> {{alias}}( x.length, 1, x, 1 )
~2.0817
- // Using `N` and `stride` parameters:
+ // Using `N` and stride parameters:
> x = new {{alias:@stdlib/array/float64}}( [ -2.0, 1.0, 1.0, -5.0, 2.0, -1.0 ] );
- > var N = {{alias:@stdlib/math/base/special/floor}}( x.length / 2 );
- > var stride = 2;
- > {{alias}}( N, 1, x, stride )
+ > {{alias}}( 3, 1, x, 2 )
~2.0817
// Using view offsets:
> var x0 = new {{alias:@stdlib/array/float64}}( [ 1.0, -2.0, 3.0, 2.0, 5.0, -1.0 ] );
> var x1 = new {{alias:@stdlib/array/float64}}( x0.buffer, x0.BYTES_PER_ELEMENT*1 );
- > N = {{alias:@stdlib/math/base/special/floor}}( x0.length / 2 );
- > stride = 2;
- > {{alias}}( N, 1, x1, stride )
+ > {{alias}}( 3, 1, x1, 2 )
~2.0817
-{{alias}}.ndarray( N, correction, x, stride, offset )
+
+{{alias}}.ndarray( N, correction, x, strideX, offsetX )
Computes the standard deviation of a double-precision floating-point strided
array using alternative indexing semantics.
@@ -89,10 +86,10 @@
x: Float64Array
Input array.
- stride: integer
- Index increment.
+ strideX: integer
+ Stride length.
- offset: integer
+ offsetX: integer
Starting index.
Returns
@@ -109,8 +106,7 @@
// Using offset parameter:
> var x = new {{alias:@stdlib/array/float64}}( [ 1.0, -2.0, 3.0, 2.0, 5.0, -1.0 ] );
- > var N = {{alias:@stdlib/math/base/special/floor}}( x.length / 2 );
- > {{alias}}.ndarray( N, 1, x, 2, 1 )
+ > {{alias}}.ndarray( 3, 1, x, 2, 1 )
~2.0817
See Also
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/examples/c/example.c b/lib/node_modules/@stdlib/stats/base/dstdev/examples/c/example.c
index db34a28ad079..7462d88050da 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/examples/c/example.c
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/examples/c/example.c
@@ -17,21 +17,20 @@
*/
#include "stdlib/stats/base/dstdev.h"
-#include
#include
int main( void ) {
// Create a strided array:
- double x[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0 };
+ const double x[] = { 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0 };
// Specify the number of elements:
- int64_t N = 4;
+ const int N = 4;
// Specify the stride length:
- int64_t stride = 2;
+ const int strideX = 2;
// Compute the standard deviation:
- double v = stdlib_strided_dstdev( N, 1, x, stride );
+ double v = stdlib_strided_dstdev( N, 1.0, x, strideX );
// Print the result:
printf( "sample standard deviation: %lf\n", v );
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/examples/index.js b/lib/node_modules/@stdlib/stats/base/dstdev/examples/index.js
index 81dc0e842d78..07c81d6d12dd 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/examples/index.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/examples/index.js
@@ -18,18 +18,12 @@
'use strict';
-var randu = require( '@stdlib/random/base/randu' );
-var round = require( '@stdlib/math/base/special/round' );
-var Float64Array = require( '@stdlib/array/float64' );
+var discreteUniform = require( '@stdlib/random/array/discrete-uniform' );
var dstdev = require( './../lib' );
-var x;
-var i;
-
-x = new Float64Array( 10 );
-for ( i = 0; i < x.length; i++ ) {
- x[ i ] = round( (randu()*100.0) - 50.0 );
-}
+var x = discreteUniform( 10, -50, 50, {
+ 'dtype': 'float64'
+});
console.log( x );
var v = dstdev( x.length, 1, x, 1 );
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/include/stdlib/stats/base/dstdev.h b/lib/node_modules/@stdlib/stats/base/dstdev/include/stdlib/stats/base/dstdev.h
index e9125c97e502..45743ef92624 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/include/stdlib/stats/base/dstdev.h
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/include/stdlib/stats/base/dstdev.h
@@ -19,7 +19,7 @@
#ifndef STDLIB_STATS_BASE_DSTDEV_H
#define STDLIB_STATS_BASE_DSTDEV_H
-#include
+#include "stdlib/blas/base/shared.h"
/*
* If C++, prevent name mangling so that the compiler emits a binary file having undecorated names, thus mirroring the behavior of a C compiler.
@@ -31,7 +31,12 @@ extern "C" {
/**
* Computes the standard deviation of a double-precision floating-point strided array.
*/
-double stdlib_strided_dstdev( const int64_t N, const double correction, const double *X, const int64_t stride );
+double API_SUFFIX(stdlib_strided_dstdev)( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX );
+
+/**
+* Computes the standard deviation of a double-precision floating-point strided array using alternative indexing semantics.
+*/
+double API_SUFFIX(stdlib_strided_dstdev_ndarray)( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX, const CBLAS_INT offsetX );
#ifdef __cplusplus
}
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/lib/index.js b/lib/node_modules/@stdlib/stats/base/dstdev/lib/index.js
index 8c34d09a54cb..393cd2b2c2ee 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/lib/index.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/lib/index.js
@@ -28,20 +28,17 @@
* var dstdev = require( '@stdlib/stats/base/dstdev' );
*
* var x = new Float64Array( [ 1.0, -2.0, 2.0 ] );
-* var N = x.length;
*
-* var v = dstdev( N, 1, x, 1 );
+* var v = dstdev( x.length, 1, x, 1 );
* // returns ~2.0817
*
* @example
* var Float64Array = require( '@stdlib/array/float64' );
-* var floor = require( '@stdlib/math/base/special/floor' );
* var dstdev = require( '@stdlib/stats/base/dstdev' );
*
* var x = new Float64Array( [ 2.0, 1.0, 2.0, -2.0, -2.0, 2.0, 3.0, 4.0 ] );
-* var N = floor( x.length / 2 );
*
-* var v = dstdev.ndarray( N, 1, x, 2, 1 );
+* var v = dstdev.ndarray( 4, 1, x, 2, 1 );
* // returns 2.5
*/
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/manifest.json b/lib/node_modules/@stdlib/stats/base/dstdev/manifest.json
index 3f08df2e1d04..4ee0352f10b5 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/manifest.json
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/manifest.json
@@ -1,6 +1,7 @@
{
"options": {
- "task": "build"
+ "task": "build",
+ "wasm": false
},
"fields": [
{
@@ -27,17 +28,17 @@
"confs": [
{
"task": "build",
+ "wasm": false,
"src": [
- "./src/dstdev.c"
+ "./src/main.c"
],
"include": [
"./include"
],
- "libraries": [
- "-lm"
- ],
+ "libraries": [],
"libpath": [],
"dependencies": [
+ "@stdlib/blas/base/shared",
"@stdlib/stats/strided/dstdevpn",
"@stdlib/napi/export",
"@stdlib/napi/argv",
@@ -49,33 +50,49 @@
},
{
"task": "benchmark",
+ "wasm": false,
"src": [
- "./src/dstdev.c"
+ "./src/main.c"
],
"include": [
"./include"
],
- "libraries": [
- "-lm"
- ],
+ "libraries": [],
"libpath": [],
"dependencies": [
+ "@stdlib/blas/base/shared",
"@stdlib/stats/strided/dstdevpn"
]
},
{
"task": "examples",
+ "wasm": false,
"src": [
- "./src/dstdev.c"
+ "./src/main.c"
],
"include": [
"./include"
],
- "libraries": [
- "-lm"
+ "libraries": [],
+ "libpath": [],
+ "dependencies": [
+ "@stdlib/blas/base/shared",
+ "@stdlib/stats/strided/dstdevpn"
+ ]
+ },
+ {
+ "task": "",
+ "wasm": true,
+ "src": [
+ "./src/main.c"
+ ],
+ "include": [
+ "./include"
],
+ "libraries": [],
"libpath": [],
"dependencies": [
+ "@stdlib/blas/base/shared",
"@stdlib/stats/strided/dstdevpn"
]
}
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/src/addon.c b/lib/node_modules/@stdlib/stats/base/dstdev/src/addon.c
index ee9ac37d3edc..8da35234f704 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/src/addon.c
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/src/addon.c
@@ -23,6 +23,7 @@
#include "stdlib/napi/argv_double.h"
#include "stdlib/napi/argv_strided_float64array.h"
#include "stdlib/napi/create_double.h"
+#include "stdlib/blas/base/shared.h"
#include
/**
@@ -35,11 +36,29 @@
static napi_value addon( napi_env env, napi_callback_info info ) {
STDLIB_NAPI_ARGV( env, info, argv, argc, 4 );
STDLIB_NAPI_ARGV_INT64( env, N, argv, 0 );
- STDLIB_NAPI_ARGV_INT64( env, stride, argv, 3 );
+ STDLIB_NAPI_ARGV_INT64( env, strideX, argv, 3 );
STDLIB_NAPI_ARGV_DOUBLE( env, correction, argv, 1 );
- STDLIB_NAPI_ARGV_STRIDED_FLOAT64ARRAY( env, X, N, stride, argv, 2 );
- STDLIB_NAPI_CREATE_DOUBLE( env, stdlib_strided_dstdev( N, correction, X, stride ), v );
+ STDLIB_NAPI_ARGV_STRIDED_FLOAT64ARRAY( env, X, N, strideX, argv, 2 );
+ STDLIB_NAPI_CREATE_DOUBLE( env, API_SUFFIX(stdlib_strided_dstdev)( N, correction, X, strideX ), v );
return v;
}
-STDLIB_NAPI_MODULE_EXPORT_FCN( addon )
+/**
+* Receives JavaScript callback invocation data.
+*
+* @param env environment under which the function is invoked
+* @param info callback data
+* @return Node-API value
+*/
+static napi_value addon_method( napi_env env, napi_callback_info info ) {
+ STDLIB_NAPI_ARGV( env, info, argv, argc, 5 );
+ STDLIB_NAPI_ARGV_INT64( env, N, argv, 0 );
+ STDLIB_NAPI_ARGV_INT64( env, strideX, argv, 3 );
+ STDLIB_NAPI_ARGV_INT64( env, offsetX, argv, 4 );
+ STDLIB_NAPI_ARGV_DOUBLE( env, correction, argv, 1 );
+ STDLIB_NAPI_ARGV_STRIDED_FLOAT64ARRAY( env, X, N, strideX, argv, 2 );
+ STDLIB_NAPI_CREATE_DOUBLE( env, API_SUFFIX(stdlib_strided_dstdev_ndarray)( N, correction, X, strideX, offsetX ), v );
+ return v;
+}
+
+STDLIB_NAPI_MODULE_EXPORT_FCN_WITH_METHOD( addon, "ndarray", addon_method )
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/src/dstdev.c b/lib/node_modules/@stdlib/stats/base/dstdev/src/dstdev.c
deleted file mode 100644
index 9ca9354183c6..000000000000
--- a/lib/node_modules/@stdlib/stats/base/dstdev/src/dstdev.c
+++ /dev/null
@@ -1,34 +0,0 @@
-/**
-* @license Apache-2.0
-*
-* Copyright (c) 2020 The Stdlib Authors.
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-* http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*/
-
-#include "stdlib/stats/base/dstdev.h"
-#include "stdlib/stats/strided/dstdevpn.h"
-#include
-
-/**
-* Computes the standard deviation of a double-precision floating-point strided array.
-*
-* @param N number of indexed elements
-* @param correction degrees of freedom adjustment
-* @param X input array
-* @param stride stride length
-* @return output value
-*/
-double stdlib_strided_dstdev( const int64_t N, const double correction, const double *X, const int64_t stride ) {
- return stdlib_strided_dstdevpn( N, correction, X, stride );
-}
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/src/main.c b/lib/node_modules/@stdlib/stats/base/dstdev/src/main.c
new file mode 100644
index 000000000000..74eeec4ad4c7
--- /dev/null
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/src/main.c
@@ -0,0 +1,48 @@
+/**
+* @license Apache-2.0
+*
+* Copyright (c) 2025 The Stdlib Authors.
+*
+* Licensed under the Apache License, Version 2.0 (the "License");
+* you may not use this file except in compliance with the License.
+* You may obtain a copy of the License at
+*
+* http://www.apache.org/licenses/LICENSE-2.0
+*
+* Unless required by applicable law or agreed to in writing, software
+* distributed under the License is distributed on an "AS IS" BASIS,
+* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+* See the License for the specific language governing permissions and
+* limitations under the License.
+*/
+
+#include "stdlib/stats/base/dstdev.h"
+#include "stdlib/stats/strided/dstdevpn.h"
+#include "stdlib/blas/base/shared.h"
+
+/**
+* Computes the standard deviation of a double-precision floating-point strided array.
+*
+* @param N number of indexed elements
+* @param correction degrees of freedom adjustment
+* @param X input array
+* @param strideX stride length
+* @return output value
+*/
+double API_SUFFIX(stdlib_strided_dstdev)( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX ) {
+ return API_SUFFIX(stdlib_strided_dstdevpn)( N, correction, X, strideX );
+}
+
+/**
+* Computes the standard deviation of a double-precision floating-point strided array using alternative indexing semantics.
+*
+* @param N number of indexed elements
+* @param correction degrees of freedom adjustment
+* @param X input array
+* @param strideX stride length
+* @param offsetX starting index for X
+* @return output value
+*/
+double API_SUFFIX(stdlib_strided_dstdev_ndarray)( const CBLAS_INT N, const double correction, const double *X, const CBLAS_INT strideX, const CBLAS_INT offsetX ) {
+ return API_SUFFIX(stdlib_strided_dstdevpn_ndarray)( N, correction, X, strideX, offsetX );
+}
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.js b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.js
index ae33ce841256..0e4ddad9d8e9 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.js
@@ -21,7 +21,6 @@
// MODULES //
var tape = require( 'tape' );
-var floor = require( '@stdlib/math/base/special/floor' );
var sqrt = require( '@stdlib/math/base/special/sqrt' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var Float64Array = require( '@stdlib/array/float64' );
@@ -122,7 +121,6 @@ tape( 'if provided a `correction` parameter yielding `N-correction` less than or
});
tape( 'the function supports a `stride` parameter', function test( t ) {
- var N;
var x;
var v;
@@ -137,15 +135,13 @@ tape( 'the function supports a `stride` parameter', function test( t ) {
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2 );
+ v = dstdev( 4, 1, x, 2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
});
tape( 'the function supports a negative `stride` parameter', function test( t ) {
- var N;
var x;
var v;
@@ -160,8 +156,7 @@ tape( 'the function supports a negative `stride` parameter', function test( t )
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, -2 );
+ v = dstdev( 4, 1, x, -2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
@@ -182,7 +177,6 @@ tape( 'if provided a `stride` parameter equal to `0`, the function returns `0`',
tape( 'the function supports view offsets', function test( t ) {
var x0;
var x1;
- var N;
var v;
x0 = new Float64Array([
@@ -198,9 +192,8 @@ tape( 'the function supports view offsets', function test( t ) {
]);
x1 = new Float64Array( x0.buffer, x0.BYTES_PER_ELEMENT*1 ); // start at 2nd element
- N = floor(x1.length / 2);
- v = dstdev( N, 1, x1, 2 );
+ v = dstdev( 4, 1, x1, 2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.native.js
index bc566cc0c03a..df6d77f156d3 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.dstdev.native.js
@@ -22,7 +22,6 @@
var resolve = require( 'path' ).resolve;
var tape = require( 'tape' );
-var floor = require( '@stdlib/math/base/special/floor' );
var sqrt = require( '@stdlib/math/base/special/sqrt' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var Float64Array = require( '@stdlib/array/float64' );
@@ -131,7 +130,6 @@ tape( 'if provided a `correction` parameter yielding `N-correction` less than or
});
tape( 'the function supports a `stride` parameter', opts, function test( t ) {
- var N;
var x;
var v;
@@ -146,15 +144,13 @@ tape( 'the function supports a `stride` parameter', opts, function test( t ) {
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2 );
+ v = dstdev( 4, 1, x, 2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
});
tape( 'the function supports a negative `stride` parameter', opts, function test( t ) {
- var N;
var x;
var v;
@@ -169,8 +165,7 @@ tape( 'the function supports a negative `stride` parameter', opts, function test
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, -2 );
+ v = dstdev( 4, 1, x, -2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
@@ -191,7 +186,6 @@ tape( 'if provided a `stride` parameter equal to `0`, the function returns `0`',
tape( 'the function supports view offsets', opts, function test( t ) {
var x0;
var x1;
- var N;
var v;
x0 = new Float64Array([
@@ -207,9 +201,8 @@ tape( 'the function supports view offsets', opts, function test( t ) {
]);
x1 = new Float64Array( x0.buffer, x0.BYTES_PER_ELEMENT*1 ); // start at 2nd element
- N = floor(x1.length / 2);
- v = dstdev( N, 1, x1, 2 );
+ v = dstdev( 4, 1, x1, 2 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.js b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.js
index 7148a305bbf5..015842e012b7 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.js
@@ -21,7 +21,6 @@
// MODULES //
var tape = require( 'tape' );
-var floor = require( '@stdlib/math/base/special/floor' );
var sqrt = require( '@stdlib/math/base/special/sqrt' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var Float64Array = require( '@stdlib/array/float64' );
@@ -122,7 +121,6 @@ tape( 'if provided a `correction` parameter yielding `N-correction` less than or
});
tape( 'the function supports a `stride` parameter', function test( t ) {
- var N;
var x;
var v;
@@ -137,15 +135,13 @@ tape( 'the function supports a `stride` parameter', function test( t ) {
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2, 0 );
+ v = dstdev( 4, 1, x, 2, 0 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
});
tape( 'the function supports a negative `stride` parameter', function test( t ) {
- var N;
var x;
var v;
@@ -160,8 +156,7 @@ tape( 'the function supports a negative `stride` parameter', function test( t )
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, -2, 6 );
+ v = dstdev( 4, 1, x, -2, 6 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
@@ -180,7 +175,6 @@ tape( 'if provided a `stride` parameter equal to `0`, the function returns `0`',
});
tape( 'the function supports an `offset` parameter', function test( t ) {
- var N;
var x;
var v;
@@ -194,9 +188,8 @@ tape( 'the function supports an `offset` parameter', function test( t ) {
3.0,
4.0 // 3
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2, 1 );
+ v = dstdev( 4, 1, x, 2, 1 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.native.js
index d78eb4d26588..1c514f599b28 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/test/test.ndarray.native.js
@@ -22,7 +22,6 @@
var resolve = require( 'path' ).resolve;
var tape = require( 'tape' );
-var floor = require( '@stdlib/math/base/special/floor' );
var sqrt = require( '@stdlib/math/base/special/sqrt' );
var isnan = require( '@stdlib/math/base/assert/is-nan' );
var Float64Array = require( '@stdlib/array/float64' );
@@ -131,7 +130,6 @@ tape( 'if provided a `correction` parameter yielding `N-correction` less than or
});
tape( 'the function supports a `stride` parameter', opts, function test( t ) {
- var N;
var x;
var v;
@@ -146,15 +144,13 @@ tape( 'the function supports a `stride` parameter', opts, function test( t ) {
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2, 0 );
+ v = dstdev( 4, 1, x, 2, 0 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
});
tape( 'the function supports a negative `stride` parameter', opts, function test( t ) {
- var N;
var x;
var v;
@@ -169,8 +165,7 @@ tape( 'the function supports a negative `stride` parameter', opts, function test
2.0
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, -2, 6 );
+ v = dstdev( 4, 1, x, -2, 6 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
@@ -189,7 +184,6 @@ tape( 'if provided a `stride` parameter equal to `0`, the function returns `0`',
});
tape( 'the function supports an `offset` parameter', opts, function test( t ) {
- var N;
var x;
var v;
@@ -203,9 +197,8 @@ tape( 'the function supports an `offset` parameter', opts, function test( t ) {
3.0,
4.0 // 3
]);
- N = floor( x.length / 2 );
- v = dstdev( N, 1, x, 2, 1 );
+ v = dstdev( 4, 1, x, 2, 1 );
t.strictEqual( v, 2.5, 'returns expected value' );
t.end();
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/docs/types/index.d.ts b/lib/node_modules/@stdlib/stats/base/dstdev/docs/types/index.d.ts
index 444e1e439190..4b5d08af6978 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/docs/types/index.d.ts
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/docs/types/index.d.ts
@@ -28,7 +28,7 @@ interface Routine {
* @param N - number of indexed elements
* @param correction - degrees of freedom adjustment
* @param x - input array
* @param stride - stride length
* @returns standard deviation
*
* @example
@@ -39,7 +39,7 @@ interface Routine {
* var v = dstdev( x.length, 1, x, 1 );
* // returns ~2.0817
*/
- ( N: number, correction: number, x: Float64Array, stride: number ): number;
+ ( N: number, correction: number, x: Float64Array, strideX: number ): number;
/**
* Computes the standard deviation of a double-precision floating-point strided array using alternative indexing semantics.
@@ -47,8 +47,8 @@ interface Routine {
* @param N - number of indexed elements
* @param correction - degrees of freedom adjustment
* @param x - input array
* @param stride - stride length
* @param offset - starting index
* @returns standard deviation
*
* @example
@@ -59,7 +59,7 @@ interface Routine {
* var v = dstdev.ndarray( x.length, 1, x, 1, 0 );
* // returns ~2.0817
*/
- ndarray( N: number, correction: number, x: Float64Array, stride: number, offset: number ): number;
+ ndarray( N: number, correction: number, x: Float64Array, strideX: number, offsetX: number ): number;
}
/**
@@ -68,7 +68,7 @@ interface Routine {
* @param N - number of indexed elements
* @param correction - degrees of freedom adjustment
* @param x - input array
* @param stride - stride length
* @returns standard deviation
*
* @example
@@ -28,7 +28,7 @@ interface Routine {
* @param correction - degrees of freedom adjustment
* @param x - input array
- * @param stride - stride length
+ * @param strideX - stride length
* @returns standard deviation
*
@@ -47,8 +47,8 @@ interface Routine {
* @param correction - degrees of freedom adjustment
* @param x - input array
- * @param stride - stride length
- * @param offset - starting index
+ * @param strideX - stride length
+ * @param offsetX - starting index
* @returns standard deviation
*
@@ -68,7 +68,7 @@ interface Routine {
* @param correction - degrees of freedom adjustment
* @param x - input array
-* @param stride - stride length
+* @param strideX - stride length
* @returns standard deviation
*
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.js b/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.js
index 26992fed6670..befd755b5a8e 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.js
@@ -31,20 +31,19 @@ var dstdevpn = require( '@stdlib/stats/strided/dstdevpn' );
* @param {PositiveInteger} N - number of indexed elements
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
* @param {integer} stride - stride length
* @returns {number} standard deviation
*
* @example
* var Float64Array = require( '@stdlib/array/float64' );
*
* var x = new Float64Array( [ 1.0, -2.0, 2.0 ] );
-* var N = x.length;
*
-* var v = dstdev( N, 1, x, 1 );
+* var v = dstdev( x.length, 1, x, 1 );
* // returns ~2.0817
*/
-function dstdev( N, correction, x, stride ) {
- return dstdevpn( N, correction, x, stride );
+function dstdev( N, correction, x, strideX ) {
+ return dstdevpn( N, correction, x, strideX );
}
@@ -31,20 +31,19 @@ var dstdevpn = require( '@stdlib/stats/strided/dstdevpn' );
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
-* @param {integer} stride - stride length
+* @param {integer} strideX - stride length
* @returns {number} standard deviation
*
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.native.js
index 4267523630bd..65f10ed41120 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/lib/dstdev.native.js
@@ -31,20 +31,19 @@ var addon = require( './../src/addon.node' );
* @param {PositiveInteger} N - number of indexed elements
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
* @param {integer} stride - stride length
* @returns {number} standard deviation
*
* @example
* var Float64Array = require( '@stdlib/array/float64' );
*
* var x = new Float64Array( [ 1.0, -2.0, 2.0 ] );
-* var N = x.length;
*
-* var v = dstdev( N, 1, x, 1 );
+* var v = dstdev( x.length, 1, x, 1 );
* // returns ~2.0817
*/
-function dstdev( N, correction, x, stride ) {
- return addon( N, correction, x, stride );
+function dstdev( N, correction, x, strideX ) {
+ return addon( N, correction, x, strideX );
}
@@ -31,20 +31,19 @@ var addon = require( './../src/addon.node' );
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
-* @param {integer} stride - stride length
+* @param {integer} strideX - stride length
* @returns {number} standard deviation
*
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.js b/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.js
index 787708058789..003d6baf170c 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.js
@@ -31,22 +31,20 @@ var dstdevpn = require( '@stdlib/stats/strided/dstdevpn' ).ndarray;
* @param {PositiveInteger} N - number of indexed elements
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
* @param {integer} stride - stride length
* @param {NonNegativeInteger} offset - starting index
* @returns {number} standard deviation
*
* @example
* var Float64Array = require( '@stdlib/array/float64' );
-* var floor = require( '@stdlib/math/base/special/floor' );
*
* var x = new Float64Array( [ 2.0, 1.0, 2.0, -2.0, -2.0, 2.0, 3.0, 4.0 ] );
-* var N = floor( x.length / 2 );
*
-* var v = dstdev( N, 1, x, 2, 1 );
+* var v = dstdev( 4, 1, x, 2, 1 );
* // returns 2.5
*/
-function dstdev( N, correction, x, stride, offset ) {
- return dstdevpn( N, correction, x, stride, offset );
+function dstdev( N, correction, x, strideX, offsetX ) {
+ return dstdevpn( N, correction, x, strideX, offsetX );
}
@@ -31,22 +31,20 @@ var dstdevpn = require( '@stdlib/stats/strided/dstdevpn' ).ndarray;
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
-* @param {integer} stride - stride length
-* @param {NonNegativeInteger} offset - starting index
+* @param {integer} strideX - stride length
+* @param {NonNegativeInteger} offsetX - starting index
* @returns {number} standard deviation
*
diff --git a/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.native.js b/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.native.js
index 6dc6cbc08525..2c2d0bcfd8c9 100644
--- a/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.native.js
+++ b/lib/node_modules/@stdlib/stats/base/dstdev/lib/ndarray.native.js
@@ -20,8 +20,7 @@
// MODULES //
-var Float64Array = require( '@stdlib/array/float64' );
-var addon = require( './dstdev.native.js' );
+var addon = require( './../src/addon.node' );
// MAIN //
@@ -32,27 +31,20 @@ var addon = require( './dstdev.native.js' );
* @param {PositiveInteger} N - number of indexed elements
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
* @param {integer} stride - stride length
* @param {NonNegativeInteger} offset - starting index
* @returns {number} standard deviation
*
* @example
* var Float64Array = require( '@stdlib/array/float64' );
-* var floor = require( '@stdlib/math/base/special/floor' );
*
* var x = new Float64Array( [ 2.0, 1.0, 2.0, -2.0, -2.0, 2.0, 3.0, 4.0 ] );
-* var N = floor( x.length / 2 );
*
-* var v = dstdev( N, 1, x, 2, 1 );
+* var v = dstdev( 4, 1, x, 2, 1 );
* // returns 2.5
*/
-function dstdev( N, correction, x, stride, offset ) {
- var view;
- if ( stride < 0 ) {
- offset += (N-1) * stride;
- }
- view = new Float64Array( x.buffer, x.byteOffset+(x.BYTES_PER_ELEMENT*offset), x.length-offset ); // eslint-disable-line max-len
- return addon( N, correction, view, stride );
+function dstdev( N, correction, x, strideX, offsetX ) {
+ return addon.ndarray( N, correction, x, strideX, offsetX );
}
@@ -32,27 +31,20 @@ var addon = require( './dstdev.native.js' );
* @param {number} correction - degrees of freedom adjustment
* @param {Float64Array} x - input array
-* @param {integer} stride - stride length
-* @param {NonNegativeInteger} offset - starting index
+* @param {integer} strideX - stride length
+* @param {NonNegativeInteger} offsetX - starting index
* @returns {number} standard deviation
*